@@ -1,5 +1,6 @@
 from commonfate_provider import provider, args, resources, tasks
 import typing
+import json
 
 from pydantic import BaseModel, Field
 
@@ -19,9 +20,6 @@ class Revoke(BaseModel):
     data: GrantData
 
 
-class Schema(BaseModel):
-    type: typing.Literal["schema"]
-
 
 class Describe(BaseModel):
     type: typing.Literal["describe"]
@@ -49,7 +47,7 @@ class LoadResources(BaseModel):
 
 class Event(BaseModel):
     __root__: typing.Union[
-        Grant, Revoke, Options, LoadResources, Schema, Describe
+        Grant, Revoke, Options, LoadResources, Describe
     ] = Field(..., discriminator="type")
 
 
@@ -86,9 +84,6 @@ class AWSLambdaRuntime:
         if isinstance(event, Options):
             self.args_cls.options(self.provider, event.data.arg)
 
-        if isinstance(event, Schema):
-            print("starting to get schema")
-            return {"target": self.args_cls.export_schema()}
 
         if isinstance(event, Describe):
             # Describe returns the configuration of the provider including the current status.
@@ -99,8 +94,9 @@ class AWSLambdaRuntime:
             result["schema"] = {}
             result["schema"]["target"] = self.args_cls.export_schema()
             result["schema"]["audit"] = resources.audit_schema()
+            result["schema"]["config"] = self.provider.export_schema()
 
-            return result
+            return json.dumps(result)
 
         elif isinstance(event, LoadResources):
             resources._reset()
